@@ -51,7 +51,6 @@ class advantage_air:
 
                         #aaAuto fix
                         for ac in data['aircons']:
-                            print(ac)
                             if data['aircons'][ac]["info"].get("aaAutoFanModeEnabled") and data[ac]["info"].get("fan") == "autoAA":
                                 data['aircons'][ac]["info"]["fan"] = "auto"
 
@@ -74,7 +73,6 @@ class advantage_air:
 
     async def async_change(self, change):
         """Merge changes with queue and send when possible, returning True when done"""
-        print(change)
         #aaAuto fix
         for ac in change:
             try:
